#
# spec file for package cozy
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           cozy
Version:        0.6.15
Release:        bp156.1.1
Summary:        Audio Book Player
License:        GPL-3.0-only
Group:          Productivity/Multimedia/Sound/Players
URL:            https://github.com/geigi
Source0:        https://github.com/geigi/cozy/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Patch0:         meson-use-python-3.6.patch
BuildRequires:  fdupes
BuildRequires:  gobject-introspection
BuildRequires:  hicolor-icon-theme
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  python3-base
BuildRequires:  python3-gobject
BuildRequires:  python3-setuptools
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(gtk+-3.0)
Requires:       python3-cairo
Requires:       python3-distro
Requires:       python3-gst
Requires:       python3-magic
Requires:       python3-mutagen
Requires:       python3-peewee
Requires:       python3-pytaglib
Requires:	python3-pytz
Requires:	python3-requests
Recommends:     %{name}-lang
Recommends:     gstreamer-plugins-base
Recommends:     gstreamer-plugins-good
Recommends:     gstreamer-plugins-ugly
Conflicts:      com.github.geigi.cozy
Provides:       com.github.geigi.cozy = %{version}
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  python3-cairo
BuildRequires:  python3-gst
BuildRequires:  python3-magic
BuildRequires:  python3-mutagen
BuildRequires:  python3-peewee
BuildRequires:  python3-pytaglib
BuildRequires:  python3-distro
# /SECTION

%description
Play and organize your audio book collection.

%lang_package

%prep
%setup -q
%if 0%{?suse_version} == 1500 && 0%{?sle_version} > 150500
%patch -P 0 -p1
%endif

%build
%meson
%meson_build

%install
%meson_install
%suse_update_desktop_file com.github.geigi.cozy
%find_lang com.github.geigi.cozy %{name}.lang
%fdupes %{buildroot}%{_datadir}
%fdupes %{buildroot}%{python3_sitelib}

%files
%defattr(0644,root,root,0755)
%license COPYING
%doc AUTHORS README.md
%attr(0755,root,root) %{_bindir}/com.github.geigi.cozy
%{_datadir}/applications/com.github.geigi.cozy.desktop
%{_datadir}/glib-2.0/schemas/com.github.geigi.cozy.gschema.xml
%{_datadir}/metainfo/com.github.geigi.cozy.appdata.xml
%{_datadir}/icons/hicolor/*/*/*.??g
%{_datadir}/com.github.geigi.cozy/
%{python3_sitelib}/cozy/

%files lang -f %{name}.lang

%changelog
* Tue Apr 16 2024 Max Lin <mlin@suse.com>
- Add meson-use-python-3.6.patch to make meson force to use
  python 3.6
* Tue Mar 17 2020 suse@geigi.de
- Update to 0.6.15
  * Fix: Files with missing tags failed to import
  * Updated translations
* Sun Mar  1 2020 suse@geigi.de
- Update to 0.6.14
  * A warning is displayed in the titlebar if network/external drives are not connected
  * MPRIS desktop integration is more stable
  * Fix: Last book was loaded on startup even when the storage medium was offline
  * Fix: Bugs in audiobook location settings window
  * Fix: Bug which sometimes could prevent playback of an audiobook
  * Fix: Crash which could occur on startup
  * Fix: Jumping in titlebar while dragging the position slider with long audio files
  * Updated translations
* Thu Feb 27 2020 Julian Geywitz <suse@geigi.de>
- Update to 0.6.13
  * Sleep timer: Automatic system power control
  * Updated translations
* Thu Feb 27 2020 Julian Geywitz <suse@geigi.de>
- Update to 0.6.13
  * Sleep timer: Automatic system power control
  * Updated translations
* Wed Jan 15 2020 suse@geigi.de
- Update to 0.6.12
  * Support for opus files
  * Support for diverse ogg cover art
  * Swedish translation
* Mon Jan  6 2020 Julian Geywitz <suse@geigi.de>
- Update to 0.6.11:
  * Fix: some valid media files were not detected
  * Support for python 3.8. Cheers to emmaliddell
  * Updated translations
  * Fixes in the titlebar
  * Fix: show navigation bar when searching from book overview
  * Other small fixes
* Mon Nov  4 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 0.6.9:
  * Remove app_menu completely
  * Version bump
  * Fix black box in icon background
* Tue Sep 17 2019 Alexei Podvalsky <avvissu@yandex.by>
- Fix error when packaging: no translations found for cozy
- Spec file cleanup
* Thu Sep 12 2019 Julian Geywitz <suse@geigi.de>
- Update to 0.6.8:
  * Cozy features a new icon! Cheers to Fatih20
  * App information is now translated! Cheers to NathanBnm
  * Updated translations
  * Fix: Sometimes the app name was not correctly displayed
* Sat Jan 12 2019 suse@geigi.de
- Update to 0.6.7:
  * Fix: Cozy crashed on startup when prefering cover image files over embedded album art
* Sat Jan 12 2019 suse@geigi.de
- Update to 0.6.6:
  * Fix: Cozy crashed on startup when prefering cover image files over embedded album art
* Mon Oct  8 2018 suse@geigi.de
- Update to 0.6.1b:
  * Fixed a bug which prevented cozy from automatically playing the next chapter
* Sat Sep  8 2018 suse@geigi.de
- Update to 0.6.1:
  * Improved artwork image quality
  * The book overview now supports multiple disks in audiobooks
  * The file not found window will only open when the file is on
    the internal drive
  * Fixed a typo
  * Support for elementaryOS 5.0
  * Updated translations
* Thu Jul 12 2018 avvissu@yandex.by
- Drop pkgconfig(granite)
* Sat Jun 23 2018 avvissu@yandex.by
- Initial package
